#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-path
version:              0.1.0.1
visibility:           public
id:                   hslua-module-path-0.1.0.1-FhdNTzVj4bYL4kbwKGVNHx
key:                  hslua-module-path-0.1.0.1-FhdNTzVj4bYL4kbwKGVNHx
license:              MIT
copyright:            © 2020-2021 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-path
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  afccafbaed3aba4d3d27e76e58e3f286
exposed:              True
exposed-modules:      Foreign.Lua.Module.Path
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hslua-module-path-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hslua-module-path-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hslua-module-path-0.1.0.1
hs-libraries:         HShslua-module-path-0.1.0.1-FhdNTzVj4bYL4kbwKGVNHx
depends:
    base-4.14.2.0 filepath-1.4.2.1 hslua-1.3.0.1-2Hqe3Gu9Y9TD4IXG266zjz
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

